@@ -209,7 +209,7 @@ class SentryClient(object):
             if request and message_id:
                 # attach the sentry object to the request
                 request.sentry = {
-                    'id': message_id,
+                    'id': '%s$%s' % (message_id, checksum),
                     'thrashed': True,
                 }
             
@@ -233,7 +233,7 @@ class SentryClient(object):
         if request:
             # attach the sentry object to the request
             request.sentry = {
-                'id': message_id,
+                'id': '%s$%s' % (message_id, checksum),
                 'thrashed': False,
             }
         
@@ -383,7 +383,10 @@ class SentryClient(object):
             )
         finally:
             if new_exc:
-                del exc_info
+                try:
+                    del exc_info
+                except Exception, e:
+                    logger.exception(e)
 
 class DummyClient(SentryClient):
     "Sends messages into an empty void"
