@@ -1,3 +1,11 @@
+"""
+sentry.plugins
+~~~~~~~~~~~~~~
+
+:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
+"""
+
 # Based on http://martyalchin.com/2008/jan/10/simple-plugin-framework/
 from django.core.urlresolvers import reverse
 
@@ -38,7 +46,7 @@ class ActionProvider:
         self.url = reverse('sentry-plugin-action', args=(self.slug,))
 
     def __call__(self, request):
-        self.selected = request.META['PATH_INFO'] == self.url
+        self.selected = request.path == self.url
         if not self.selected:
             return
 
@@ -59,7 +67,7 @@ class GroupActionProvider:
         self.url = self.__class__.get_url(group_id)
 
     def __call__(self, request, group):
-        self.selected = request.META['PATH_INFO'] == self.url
+        self.selected = request.path == self.url
         if not self.selected:
             return
         return self.view(request, group)
@@ -84,4 +92,4 @@ class GroupActionProvider:
     def widget(self, request, group):
         """
         Renders as a widget in the group details sidebar.
-        """
\ No newline at end of file
+        """
